@@ -5,7 +5,7 @@ import actelink.models as models
 api = Api()
 
 #TODO: request validation vs. schema
-@api.route('/_computations/', methods=['POST'])
+@api.route('/_computations', methods=['POST'])
 class Computations(Resource):
     @api.doc(responses={
         200: 'Success',
