@@ -32,5 +32,5 @@ def start():
     app = create_app()
     # start flask server
     log.debug(f"Starting app in {app.config['ENV']} environment on {settings.HOST}:{settings.PORT}")
-    app.run(host=settings.HOST, port=settings.PORT, use_reloader=False)
-    #StandaloneApplication(app, options).run()
+    #app.run(host=settings.HOST, port=settings.PORT, use_reloader=False)
+    StandaloneApplication(app, options).run()
